pub struct ScaleFactor(/* private fields */);Expand description
The ratio of physical device pixels to logical pixels for a surface
(e.g. 2.0 on a typical HiDPI “retina” display, 1.0 on a standard
display). Always strictly positive.
Implementations
Sourceimpl ScaleFactor
impl ScaleFactor
Sourcepub fn new(factor: f64) -> Self
pub fn new(factor: f64) -> Self
Creates a scale factor, clamping non-finite or non-positive input to
ScaleFactor::IDENTITY.
pub fn get(self) -> f64
Sourcepub fn to_physical(self, logical: Size) -> PhysicalSize
pub fn to_physical(self, logical: Size) -> PhysicalSize
Convert a logical size to physical pixels, rounding to whole pixels.
Sourcepub fn to_logical(self, physical: PhysicalSize) -> Size
pub fn to_logical(self, physical: PhysicalSize) -> Size
Convert a physical size back to logical pixels.